@@ -1,3 +1,4 @@
+from __future__ import annotations
 from parchmint.layer import Layer
 from typing import List, Optional
 from parchmint.params import Params
@@ -5,7 +6,7 @@ from parchmint.target import Target
 
 
 class Connection:
-    def __init__(self, json=None):
+    def __init__(self, json=None, device_ref=None):
 
         self.name: Optional[str] = None
         self.ID: str = ""
@@ -16,12 +17,22 @@ class Connection:
         self.layer: Layer = None
 
         if json:
-            self.parse_from_json(json)
+            if device_ref is None:
+                raise Exception(
+                    "Cannot Parse Connection from JSON with no Device Reference, check device_ref parameter in constructor "
+                )
+
+            self.parse_from_json(json, device_ref)
+
+    def parse_from_json(self, json, device_ref=None):
+        if device_ref is None:
+            raise Exception(
+                "Cannot Parse Connection from JSON with no Device Reference, check device_ref parameter in constructor "
+            )
 
-    def parse_from_json(self, json):
         self.name = json["name"]
         self.ID = json["id"]
-        self.layer = json["layer"]
+        self.layer = device_ref.get_layer(json["layer"])
         self.params = Params(json["params"])
 
         self.source = Target(json["source"])
